# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class ModelResultStationWqStatisticOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key_section_location': 'str',
        'arrive_time': 'str',
        'leave_time': 'str',
        'max_value': 'float',
        'max_time': 'str',
        'ts_pairs': 'list[TsPairObject]'
    }

    attribute_map = {
        'key_section_location': 'keySectionLocation',
        'arrive_time': 'arriveTime',
        'leave_time': 'leaveTime',
        'max_value': 'maxValue',
        'max_time': 'maxTime',
        'ts_pairs': 'tsPairs'
    }

    def __init__(self, key_section_location=None, arrive_time=None, leave_time=None, max_value=None, max_time=None, ts_pairs=None, local_vars_configuration=None):  # noqa: E501
        """ModelResultStationWqStatisticOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key_section_location = None
        self._arrive_time = None
        self._leave_time = None
        self._max_value = None
        self._max_time = None
        self._ts_pairs = None
        self.discriminator = None

        self.key_section_location = key_section_location
        self.arrive_time = arrive_time
        self.leave_time = leave_time
        if max_value is not None:
            self.max_value = max_value
        self.max_time = max_time
        self.ts_pairs = ts_pairs

    @property
    def key_section_location(self):
        """Gets the key_section_location of this ModelResultStationWqStatisticOutput.  # noqa: E501

        考核断面（河道名，里程）assessment section (river name, chainage)  # noqa: E501

        :return: The key_section_location of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._key_section_location

    @key_section_location.setter
    def key_section_location(self, key_section_location):
        """Sets the key_section_location of this ModelResultStationWqStatisticOutput.

        考核断面（河道名，里程）assessment section (river name, chainage)  # noqa: E501

        :param key_section_location: The key_section_location of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :type: str
        """

        self._key_section_location = key_section_location

    @property
    def arrive_time(self):
        """Gets the arrive_time of this ModelResultStationWqStatisticOutput.  # noqa: E501

        到达时间 arrive time  # noqa: E501

        :return: The arrive_time of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._arrive_time

    @arrive_time.setter
    def arrive_time(self, arrive_time):
        """Sets the arrive_time of this ModelResultStationWqStatisticOutput.

        到达时间 arrive time  # noqa: E501

        :param arrive_time: The arrive_time of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :type: str
        """

        self._arrive_time = arrive_time

    @property
    def leave_time(self):
        """Gets the leave_time of this ModelResultStationWqStatisticOutput.  # noqa: E501

        离开时间 leave time  # noqa: E501

        :return: The leave_time of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._leave_time

    @leave_time.setter
    def leave_time(self, leave_time):
        """Sets the leave_time of this ModelResultStationWqStatisticOutput.

        离开时间 leave time  # noqa: E501

        :param leave_time: The leave_time of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :type: str
        """

        self._leave_time = leave_time

    @property
    def max_value(self):
        """Gets the max_value of this ModelResultStationWqStatisticOutput.  # noqa: E501

        最大浓度值 maximum concentration value  # noqa: E501

        :return: The max_value of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this ModelResultStationWqStatisticOutput.

        最大浓度值 maximum concentration value  # noqa: E501

        :param max_value: The max_value of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def max_time(self):
        """Gets the max_time of this ModelResultStationWqStatisticOutput.  # noqa: E501

        最大浓度时刻 time of maximum concentration  # noqa: E501

        :return: The max_time of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._max_time

    @max_time.setter
    def max_time(self, max_time):
        """Sets the max_time of this ModelResultStationWqStatisticOutput.

        最大浓度时刻 time of maximum concentration  # noqa: E501

        :param max_time: The max_time of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :type: str
        """

        self._max_time = max_time

    @property
    def ts_pairs(self):
        """Gets the ts_pairs of this ModelResultStationWqStatisticOutput.  # noqa: E501

        污染物浓度变化过程 time series of pollutant concentration change process  # noqa: E501

        :return: The ts_pairs of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :rtype: list[TsPairObject]
        """
        return self._ts_pairs

    @ts_pairs.setter
    def ts_pairs(self, ts_pairs):
        """Sets the ts_pairs of this ModelResultStationWqStatisticOutput.

        污染物浓度变化过程 time series of pollutant concentration change process  # noqa: E501

        :param ts_pairs: The ts_pairs of this ModelResultStationWqStatisticOutput.  # noqa: E501
        :type: list[TsPairObject]
        """

        self._ts_pairs = ts_pairs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelResultStationWqStatisticOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelResultStationWqStatisticOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class DamGateStatusInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenario_id': 'str',
        'dam_gate_code': 'str',
        'sort': 'int',
        'status': 'str',
        'is_scheduling': 'bool',
        'tag_weir_height': 'float'
    }

    attribute_map = {
        'scenario_id': 'scenarioId',
        'dam_gate_code': 'damGateCode',
        'sort': 'sort',
        'status': 'status',
        'is_scheduling': 'isScheduling',
        'tag_weir_height': 'tagWeirHeight'
    }

    def __init__(self, scenario_id=None, dam_gate_code=None, sort=None, status=None, is_scheduling=None, tag_weir_height=None, local_vars_configuration=None):  # noqa: E501
        """DamGateStatusInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenario_id = None
        self._dam_gate_code = None
        self._sort = None
        self._status = None
        self._is_scheduling = None
        self._tag_weir_height = None
        self.discriminator = None

        if scenario_id is not None:
            self.scenario_id = scenario_id
        self.dam_gate_code = dam_gate_code
        if sort is not None:
            self.sort = sort
        self.status = status
        if is_scheduling is not None:
            self.is_scheduling = is_scheduling
        self.tag_weir_height = tag_weir_height

    @property
    def scenario_id(self):
        """Gets the scenario_id of this DamGateStatusInfo.  # noqa: E501

        方案ID  # noqa: E501

        :return: The scenario_id of this DamGateStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this DamGateStatusInfo.

        方案ID  # noqa: E501

        :param scenario_id: The scenario_id of this DamGateStatusInfo.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def dam_gate_code(self):
        """Gets the dam_gate_code of this DamGateStatusInfo.  # noqa: E501

        堰门编码,iot中堰的名称  # noqa: E501

        :return: The dam_gate_code of this DamGateStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._dam_gate_code

    @dam_gate_code.setter
    def dam_gate_code(self, dam_gate_code):
        """Sets the dam_gate_code of this DamGateStatusInfo.

        堰门编码,iot中堰的名称  # noqa: E501

        :param dam_gate_code: The dam_gate_code of this DamGateStatusInfo.  # noqa: E501
        :type: str
        """

        self._dam_gate_code = dam_gate_code

    @property
    def sort(self):
        """Gets the sort of this DamGateStatusInfo.  # noqa: E501

        排序号,越小越靠前  # noqa: E501

        :return: The sort of this DamGateStatusInfo.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this DamGateStatusInfo.

        排序号,越小越靠前  # noqa: E501

        :param sort: The sort of this DamGateStatusInfo.  # noqa: E501
        :type: int
        """

        self._sort = sort

    @property
    def status(self):
        """Gets the status of this DamGateStatusInfo.  # noqa: E501

        状态枚举: Usable :0可用的; Unusable :1不可用的  # noqa: E501

        :return: The status of this DamGateStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DamGateStatusInfo.

        状态枚举: Usable :0可用的; Unusable :1不可用的  # noqa: E501

        :param status: The status of this DamGateStatusInfo.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def is_scheduling(self):
        """Gets the is_scheduling of this DamGateStatusInfo.  # noqa: E501

        是否可调度  # noqa: E501

        :return: The is_scheduling of this DamGateStatusInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_scheduling

    @is_scheduling.setter
    def is_scheduling(self, is_scheduling):
        """Sets the is_scheduling of this DamGateStatusInfo.

        是否可调度  # noqa: E501

        :param is_scheduling: The is_scheduling of this DamGateStatusInfo.  # noqa: E501
        :type: bool
        """

        self._is_scheduling = is_scheduling

    @property
    def tag_weir_height(self):
        """Gets the tag_weir_height of this DamGateStatusInfo.  # noqa: E501

        人工标定堰高  # noqa: E501

        :return: The tag_weir_height of this DamGateStatusInfo.  # noqa: E501
        :rtype: float
        """
        return self._tag_weir_height

    @tag_weir_height.setter
    def tag_weir_height(self, tag_weir_height):
        """Sets the tag_weir_height of this DamGateStatusInfo.

        人工标定堰高  # noqa: E501

        :param tag_weir_height: The tag_weir_height of this DamGateStatusInfo.  # noqa: E501
        :type: float
        """

        self._tag_weir_height = tag_weir_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DamGateStatusInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DamGateStatusInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class ModelResultRiverWqStatisticOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'model_feature_id': 'str',
        'control_rate': 'float',
        'exceed_period': 'float',
        'wq_infos': 'list[WqMaxStatistic]'
    }

    attribute_map = {
        'model_feature_id': 'modelFeatureId',
        'control_rate': 'controlRate',
        'exceed_period': 'exceedPeriod',
        'wq_infos': 'wqInfos'
    }

    def __init__(self, model_feature_id=None, control_rate=None, exceed_period=None, wq_infos=None, local_vars_configuration=None):  # noqa: E501
        """ModelResultRiverWqStatisticOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._model_feature_id = None
        self._control_rate = None
        self._exceed_period = None
        self._wq_infos = None
        self.discriminator = None

        self.model_feature_id = model_feature_id
        if control_rate is not None:
            self.control_rate = control_rate
        if exceed_period is not None:
            self.exceed_period = exceed_period
        self.wq_infos = wq_infos

    @property
    def model_feature_id(self):
        """Gets the model_feature_id of this ModelResultRiverWqStatisticOutput.  # noqa: E501

        模型文件里元素的ID modelfeature id  # noqa: E501

        :return: The model_feature_id of this ModelResultRiverWqStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_feature_id

    @model_feature_id.setter
    def model_feature_id(self, model_feature_id):
        """Sets the model_feature_id of this ModelResultRiverWqStatisticOutput.

        模型文件里元素的ID modelfeature id  # noqa: E501

        :param model_feature_id: The model_feature_id of this ModelResultRiverWqStatisticOutput.  # noqa: E501
        :type: str
        """

        self._model_feature_id = model_feature_id

    @property
    def control_rate(self):
        """Gets the control_rate of this ModelResultRiverWqStatisticOutput.  # noqa: E501

        水质达标率 water quality compliance rate  # noqa: E501

        :return: The control_rate of this ModelResultRiverWqStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._control_rate

    @control_rate.setter
    def control_rate(self, control_rate):
        """Sets the control_rate of this ModelResultRiverWqStatisticOutput.

        水质达标率 water quality compliance rate  # noqa: E501

        :param control_rate: The control_rate of this ModelResultRiverWqStatisticOutput.  # noqa: E501
        :type: float
        """

        self._control_rate = control_rate

    @property
    def exceed_period(self):
        """Gets the exceed_period of this ModelResultRiverWqStatisticOutput.  # noqa: E501

        超标时间(h) exceedance time (unit:h)  # noqa: E501

        :return: The exceed_period of this ModelResultRiverWqStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._exceed_period

    @exceed_period.setter
    def exceed_period(self, exceed_period):
        """Sets the exceed_period of this ModelResultRiverWqStatisticOutput.

        超标时间(h) exceedance time (unit:h)  # noqa: E501

        :param exceed_period: The exceed_period of this ModelResultRiverWqStatisticOutput.  # noqa: E501
        :type: float
        """

        self._exceed_period = exceed_period

    @property
    def wq_infos(self):
        """Gets the wq_infos of this ModelResultRiverWqStatisticOutput.  # noqa: E501

        水质最大值集合 collection of water quality maximums  # noqa: E501

        :return: The wq_infos of this ModelResultRiverWqStatisticOutput.  # noqa: E501
        :rtype: list[WqMaxStatistic]
        """
        return self._wq_infos

    @wq_infos.setter
    def wq_infos(self, wq_infos):
        """Sets the wq_infos of this ModelResultRiverWqStatisticOutput.

        水质最大值集合 collection of water quality maximums  # noqa: E501

        :param wq_infos: The wq_infos of this ModelResultRiverWqStatisticOutput.  # noqa: E501
        :type: list[WqMaxStatistic]
        """

        self._wq_infos = wq_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelResultRiverWqStatisticOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelResultRiverWqStatisticOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class TimeSpan(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ticks': 'int',
        'days': 'int',
        'hours': 'int',
        'milliseconds': 'int',
        'microseconds': 'int',
        'nanoseconds': 'int',
        'minutes': 'int',
        'seconds': 'int',
        'total_days': 'float',
        'total_hours': 'float',
        'total_milliseconds': 'float',
        'total_microseconds': 'float',
        'total_nanoseconds': 'float',
        'total_minutes': 'float',
        'total_seconds': 'float'
    }

    attribute_map = {
        'ticks': 'ticks',
        'days': 'days',
        'hours': 'hours',
        'milliseconds': 'milliseconds',
        'microseconds': 'microseconds',
        'nanoseconds': 'nanoseconds',
        'minutes': 'minutes',
        'seconds': 'seconds',
        'total_days': 'totalDays',
        'total_hours': 'totalHours',
        'total_milliseconds': 'totalMilliseconds',
        'total_microseconds': 'totalMicroseconds',
        'total_nanoseconds': 'totalNanoseconds',
        'total_minutes': 'totalMinutes',
        'total_seconds': 'totalSeconds'
    }

    def __init__(self, ticks=None, days=None, hours=None, milliseconds=None, microseconds=None, nanoseconds=None, minutes=None, seconds=None, total_days=None, total_hours=None, total_milliseconds=None, total_microseconds=None, total_nanoseconds=None, total_minutes=None, total_seconds=None, local_vars_configuration=None):  # noqa: E501
        """TimeSpan - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ticks = None
        self._days = None
        self._hours = None
        self._milliseconds = None
        self._microseconds = None
        self._nanoseconds = None
        self._minutes = None
        self._seconds = None
        self._total_days = None
        self._total_hours = None
        self._total_milliseconds = None
        self._total_microseconds = None
        self._total_nanoseconds = None
        self._total_minutes = None
        self._total_seconds = None
        self.discriminator = None

        if ticks is not None:
            self.ticks = ticks
        if days is not None:
            self.days = days
        if hours is not None:
            self.hours = hours
        if milliseconds is not None:
            self.milliseconds = milliseconds
        if microseconds is not None:
            self.microseconds = microseconds
        if nanoseconds is not None:
            self.nanoseconds = nanoseconds
        if minutes is not None:
            self.minutes = minutes
        if seconds is not None:
            self.seconds = seconds
        if total_days is not None:
            self.total_days = total_days
        if total_hours is not None:
            self.total_hours = total_hours
        if total_milliseconds is not None:
            self.total_milliseconds = total_milliseconds
        if total_microseconds is not None:
            self.total_microseconds = total_microseconds
        if total_nanoseconds is not None:
            self.total_nanoseconds = total_nanoseconds
        if total_minutes is not None:
            self.total_minutes = total_minutes
        if total_seconds is not None:
            self.total_seconds = total_seconds

    @property
    def ticks(self):
        """Gets the ticks of this TimeSpan.  # noqa: E501


        :return: The ticks of this TimeSpan.  # noqa: E501
        :rtype: int
        """
        return self._ticks

    @ticks.setter
    def ticks(self, ticks):
        """Sets the ticks of this TimeSpan.


        :param ticks: The ticks of this TimeSpan.  # noqa: E501
        :type: int
        """

        self._ticks = ticks

    @property
    def days(self):
        """Gets the days of this TimeSpan.  # noqa: E501


        :return: The days of this TimeSpan.  # noqa: E501
        :rtype: int
        """
        return self._days

    @days.setter
    def days(self, days):
        """Sets the days of this TimeSpan.


        :param days: The days of this TimeSpan.  # noqa: E501
        :type: int
        """

        self._days = days

    @property
    def hours(self):
        """Gets the hours of this TimeSpan.  # noqa: E501


        :return: The hours of this TimeSpan.  # noqa: E501
        :rtype: int
        """
        return self._hours

    @hours.setter
    def hours(self, hours):
        """Sets the hours of this TimeSpan.


        :param hours: The hours of this TimeSpan.  # noqa: E501
        :type: int
        """

        self._hours = hours

    @property
    def milliseconds(self):
        """Gets the milliseconds of this TimeSpan.  # noqa: E501


        :return: The milliseconds of this TimeSpan.  # noqa: E501
        :rtype: int
        """
        return self._milliseconds

    @milliseconds.setter
    def milliseconds(self, milliseconds):
        """Sets the milliseconds of this TimeSpan.


        :param milliseconds: The milliseconds of this TimeSpan.  # noqa: E501
        :type: int
        """

        self._milliseconds = milliseconds

    @property
    def microseconds(self):
        """Gets the microseconds of this TimeSpan.  # noqa: E501


        :return: The microseconds of this TimeSpan.  # noqa: E501
        :rtype: int
        """
        return self._microseconds

    @microseconds.setter
    def microseconds(self, microseconds):
        """Sets the microseconds of this TimeSpan.


        :param microseconds: The microseconds of this TimeSpan.  # noqa: E501
        :type: int
        """

        self._microseconds = microseconds

    @property
    def nanoseconds(self):
        """Gets the nanoseconds of this TimeSpan.  # noqa: E501


        :return: The nanoseconds of this TimeSpan.  # noqa: E501
        :rtype: int
        """
        return self._nanoseconds

    @nanoseconds.setter
    def nanoseconds(self, nanoseconds):
        """Sets the nanoseconds of this TimeSpan.


        :param nanoseconds: The nanoseconds of this TimeSpan.  # noqa: E501
        :type: int
        """

        self._nanoseconds = nanoseconds

    @property
    def minutes(self):
        """Gets the minutes of this TimeSpan.  # noqa: E501


        :return: The minutes of this TimeSpan.  # noqa: E501
        :rtype: int
        """
        return self._minutes

    @minutes.setter
    def minutes(self, minutes):
        """Sets the minutes of this TimeSpan.


        :param minutes: The minutes of this TimeSpan.  # noqa: E501
        :type: int
        """

        self._minutes = minutes

    @property
    def seconds(self):
        """Gets the seconds of this TimeSpan.  # noqa: E501


        :return: The seconds of this TimeSpan.  # noqa: E501
        :rtype: int
        """
        return self._seconds

    @seconds.setter
    def seconds(self, seconds):
        """Sets the seconds of this TimeSpan.


        :param seconds: The seconds of this TimeSpan.  # noqa: E501
        :type: int
        """

        self._seconds = seconds

    @property
    def total_days(self):
        """Gets the total_days of this TimeSpan.  # noqa: E501


        :return: The total_days of this TimeSpan.  # noqa: E501
        :rtype: float
        """
        return self._total_days

    @total_days.setter
    def total_days(self, total_days):
        """Sets the total_days of this TimeSpan.


        :param total_days: The total_days of this TimeSpan.  # noqa: E501
        :type: float
        """

        self._total_days = total_days

    @property
    def total_hours(self):
        """Gets the total_hours of this TimeSpan.  # noqa: E501


        :return: The total_hours of this TimeSpan.  # noqa: E501
        :rtype: float
        """
        return self._total_hours

    @total_hours.setter
    def total_hours(self, total_hours):
        """Sets the total_hours of this TimeSpan.


        :param total_hours: The total_hours of this TimeSpan.  # noqa: E501
        :type: float
        """

        self._total_hours = total_hours

    @property
    def total_milliseconds(self):
        """Gets the total_milliseconds of this TimeSpan.  # noqa: E501


        :return: The total_milliseconds of this TimeSpan.  # noqa: E501
        :rtype: float
        """
        return self._total_milliseconds

    @total_milliseconds.setter
    def total_milliseconds(self, total_milliseconds):
        """Sets the total_milliseconds of this TimeSpan.


        :param total_milliseconds: The total_milliseconds of this TimeSpan.  # noqa: E501
        :type: float
        """

        self._total_milliseconds = total_milliseconds

    @property
    def total_microseconds(self):
        """Gets the total_microseconds of this TimeSpan.  # noqa: E501


        :return: The total_microseconds of this TimeSpan.  # noqa: E501
        :rtype: float
        """
        return self._total_microseconds

    @total_microseconds.setter
    def total_microseconds(self, total_microseconds):
        """Sets the total_microseconds of this TimeSpan.


        :param total_microseconds: The total_microseconds of this TimeSpan.  # noqa: E501
        :type: float
        """

        self._total_microseconds = total_microseconds

    @property
    def total_nanoseconds(self):
        """Gets the total_nanoseconds of this TimeSpan.  # noqa: E501


        :return: The total_nanoseconds of this TimeSpan.  # noqa: E501
        :rtype: float
        """
        return self._total_nanoseconds

    @total_nanoseconds.setter
    def total_nanoseconds(self, total_nanoseconds):
        """Sets the total_nanoseconds of this TimeSpan.


        :param total_nanoseconds: The total_nanoseconds of this TimeSpan.  # noqa: E501
        :type: float
        """

        self._total_nanoseconds = total_nanoseconds

    @property
    def total_minutes(self):
        """Gets the total_minutes of this TimeSpan.  # noqa: E501


        :return: The total_minutes of this TimeSpan.  # noqa: E501
        :rtype: float
        """
        return self._total_minutes

    @total_minutes.setter
    def total_minutes(self, total_minutes):
        """Sets the total_minutes of this TimeSpan.


        :param total_minutes: The total_minutes of this TimeSpan.  # noqa: E501
        :type: float
        """

        self._total_minutes = total_minutes

    @property
    def total_seconds(self):
        """Gets the total_seconds of this TimeSpan.  # noqa: E501


        :return: The total_seconds of this TimeSpan.  # noqa: E501
        :rtype: float
        """
        return self._total_seconds

    @total_seconds.setter
    def total_seconds(self, total_seconds):
        """Sets the total_seconds of this TimeSpan.


        :param total_seconds: The total_seconds of this TimeSpan.  # noqa: E501
        :type: float
        """

        self._total_seconds = total_seconds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimeSpan):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TimeSpan):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_result_analysis_service.api_client import ApiClient
from dhicn_result_analysis_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class RiverApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_result_river_dynamic_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道动态结果数据 Get 1D dynamic results of river  # noqa: E501

        获取河道水位、流量的动态变化结果 Get river dynamic results including water level, discharge of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_dynamic_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str river_data_type: 河道结果类型 river result type:  0-WaterLevel;  1-Discharge
        :param int frequency: 提取结果的时间频率 time frequency used to get result
        :param str start_time: 提取结果的开始时间 start time used to get result
        :param str end_time: 提取结果的结束时间 end time used to get result
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseDynamicOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_river_dynamic_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_river_dynamic_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道动态结果数据 Get 1D dynamic results of river  # noqa: E501

        获取河道水位、流量的动态变化结果 Get river dynamic results including water level, discharge of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_dynamic_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str river_data_type: 河道结果类型 river result type:  0-WaterLevel;  1-Discharge
        :param int frequency: 提取结果的时间频率 time frequency used to get result
        :param str start_time: 提取结果的开始时间 start time used to get result
        :param str end_time: 提取结果的结束时间 end time used to get result
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseDynamicOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'river_data_type',
            'frequency',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_river_dynamic_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_river_dynamic_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'river_data_type' in local_var_params and local_var_params['river_data_type'] is not None:  # noqa: E501
            query_params.append(('RiverDataType', local_var_params['river_data_type']))  # noqa: E501
        if 'frequency' in local_var_params and local_var_params['frequency'] is not None:  # noqa: E501
            query_params.append(('Frequency', local_var_params['frequency']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('StartTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('EndTime', local_var_params['end_time']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/river/dynamic', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseDynamicOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_river_gate_statistics_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道闸门的统计结果 Get statistic result of river gates  # noqa: E501

        获取河道闸门的统计结果数据，包括累计开启时长等 Get river structure gates statistic results, including gate accumulated open time, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_gate_statistics_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GateStatisticsOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_river_gate_statistics_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_river_gate_statistics_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道闸门的统计结果 Get statistic result of river gates  # noqa: E501

        获取河道闸门的统计结果数据，包括累计开启时长等 Get river structure gates statistic results, including gate accumulated open time, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_gate_statistics_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GateStatisticsOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_river_gate_statistics_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_river_gate_statistics_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/river/gate-statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GateStatisticsOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_river_profile_timeseries_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道剖面图数据 Get river profile plot data  # noqa: E501

        获取指定河段上的剖面图数据 Get profile plot data of a river branch of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_profile_timeseries_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] river_id: 河道ID
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RiverProfile
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_river_profile_timeseries_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_river_profile_timeseries_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道剖面图数据 Get river profile plot data  # noqa: E501

        获取指定河段上的剖面图数据 Get profile plot data of a river branch of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_profile_timeseries_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param list[str] river_id: 河道ID
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RiverProfile, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'river_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_river_profile_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_river_profile_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'river_id' in local_var_params and local_var_params['river_id'] is not None:  # noqa: E501
            query_params.append(('RiverID', local_var_params['river_id']))  # noqa: E501
            collection_formats['RiverID'] = 'multi'  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/river/profile-timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RiverProfile',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_river_pump_statistics_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道泵站统计结果 Get statistic result of river pumps  # noqa: E501

        获取河道泵站的统计结果数据，包括累计流量、累计开启时长等 Get river structure pumps statistic results, including pump accumulated discharge, pump accumulated open time, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_pump_statistics_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PumpStatisticsOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_river_pump_statistics_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_river_pump_statistics_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道泵站统计结果 Get statistic result of river pumps  # noqa: E501

        获取河道泵站的统计结果数据，包括累计流量、累计开启时长等 Get river structure pumps statistic results, including pump accumulated discharge, pump accumulated open time, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_pump_statistics_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PumpStatisticsOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_river_pump_statistics_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_river_pump_statistics_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/river/pump-statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PumpStatisticsOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_river_pump_timeseries_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道泵站的时间序列结果 Get time-series result of river pumps  # noqa: E501

        获取河道泵站的水位、流量时间序列结果 Get water level or discharge time series result of a single river pump of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_pump_timeseries_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pump_id: 泵的ID pump ID
        :param str pump_data_type: 泵的数据类型 pump data type:  0-WaterLevel;  1-Discharge;
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseTimeseriesOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_river_pump_timeseries_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_river_pump_timeseries_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道泵站的时间序列结果 Get time-series result of river pumps  # noqa: E501

        获取河道泵站的水位、流量时间序列结果 Get water level or discharge time series result of a single river pump of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_pump_timeseries_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str pump_id: 泵的ID pump ID
        :param str pump_data_type: 泵的数据类型 pump data type:  0-WaterLevel;  1-Discharge;
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseTimeseriesOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'pump_id',
            'pump_data_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_river_pump_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_river_pump_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pump_id' in local_var_params and local_var_params['pump_id'] is not None:  # noqa: E501
            query_params.append(('PumpID', local_var_params['pump_id']))  # noqa: E501
        if 'pump_data_type' in local_var_params and local_var_params['pump_data_type'] is not None:  # noqa: E501
            query_params.append(('PumpDataType', local_var_params['pump_data_type']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/river/pump-timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseTimeseriesOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_river_static_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道静态结果数据 Get 1D static results of river  # noqa: E501

        获取河道统计结果，包括最大水位、流量，最小水位、流量 Get river statistic results including maximum and minimum of water level, discharge of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_static_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str river_data_type: 河道结果类型 river result type:  0-WaterLevel;  1-Discharge;
        :param str statistic_type: 统计类型 statistic type:  0-Min;  1-Max
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseStaticOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_river_static_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_river_static_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道静态结果数据 Get 1D static results of river  # noqa: E501

        获取河道统计结果，包括最大水位、流量，最小水位、流量 Get river statistic results including maximum and minimum of water level, discharge of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_static_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str river_data_type: 河道结果类型 river result type:  0-WaterLevel;  1-Discharge;
        :param str statistic_type: 统计类型 statistic type:  0-Min;  1-Max
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseStaticOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'river_data_type',
            'statistic_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_river_static_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_river_static_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'river_data_type' in local_var_params and local_var_params['river_data_type'] is not None:  # noqa: E501
            query_params.append(('RiverDataType', local_var_params['river_data_type']))  # noqa: E501
        if 'statistic_type' in local_var_params and local_var_params['statistic_type'] is not None:  # noqa: E501
            query_params.append(('StatisticType', local_var_params['statistic_type']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/river/static', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseStaticOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_result_river_timeseries_get(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道单点时间序列结果 Get single-point time-series result on the river  # noqa: E501

        获取指定河道计算点上的水位、流量时间序列结果数据 Get river water level or discharge time series result on a single river point of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_timeseries_get(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str river_data_type: 河道结果类型 river result type:  0-WaterLevel;  1-Discharge
        :param str river_id: 河道ID river ID
        :param float chainage: 河道计算点里程 river point chainage
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BaseTimeseriesOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_result_river_timeseries_get_with_http_info(scenario_id, **kwargs)  # noqa: E501

    def api_v1_result_river_timeseries_get_with_http_info(self, scenario_id, **kwargs):  # noqa: E501
        """获取河道单点时间序列结果 Get single-point time-series result on the river  # noqa: E501

        获取指定河道计算点上的水位、流量时间序列结果数据 Get river water level or discharge time series result on a single river point of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_result_river_timeseries_get_with_http_info(scenario_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案的ID scenario’s ID (required)
        :param str river_data_type: 河道结果类型 river result type:  0-WaterLevel;  1-Discharge
        :param str river_id: 河道ID river ID
        :param float chainage: 河道计算点里程 river point chainage
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BaseTimeseriesOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'river_data_type',
            'river_id',
            'chainage'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_result_river_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'scenario_id' is set
        if self.api_client.client_side_validation and ('scenario_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['scenario_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `scenario_id` when calling `api_v1_result_river_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'river_data_type' in local_var_params and local_var_params['river_data_type'] is not None:  # noqa: E501
            query_params.append(('RiverDataType', local_var_params['river_data_type']))  # noqa: E501
        if 'river_id' in local_var_params and local_var_params['river_id'] is not None:  # noqa: E501
            query_params.append(('RiverId', local_var_params['river_id']))  # noqa: E501
        if 'chainage' in local_var_params and local_var_params['chainage'] is not None:  # noqa: E501
            query_params.append(('Chainage', local_var_params['chainage']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/result/river/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseTimeseriesOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_wwtp_data_bus_service.api_client import ApiClient
from dhicn_wwtp_data_bus_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class IntelligentDenitrificationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_intelligent_denitrification_download_dosing_log_get(self, **kwargs):  # noqa: E501
        """指定时间段内加药报表文件导出 Export dosing logs of a certain period as an excel file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_download_dosing_log_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类型 dosage type
        :param str production_line: 产线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str download_key: 下载key download key
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_download_dosing_log_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_download_dosing_log_get_with_http_info(self, **kwargs):  # noqa: E501
        """指定时间段内加药报表文件导出 Export dosing logs of a certain period as an excel file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_download_dosing_log_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类型 dosage type
        :param str production_line: 产线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str download_key: 下载key download key
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'category',
            'production_line',
            'start_time',
            'end_time',
            'download_key'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_download_dosing_log_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'category' in local_var_params and local_var_params['category'] is not None:  # noqa: E501
            query_params.append(('category', local_var_params['category']))  # noqa: E501
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501
        if 'download_key' in local_var_params and local_var_params['download_key'] is not None:  # noqa: E501
            query_params.append(('downloadKey', local_var_params['download_key']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/DownloadDosingLog', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_download_dosing_statistic_daily_get(self, **kwargs):  # noqa: E501
        """指定时间段内加药统计文件导出 Export dosing daily statistic results of a certain period as an excel file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_download_dosing_statistic_daily_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类型 dosage type
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str download_key: 下载key download key
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_download_dosing_statistic_daily_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_download_dosing_statistic_daily_get_with_http_info(self, **kwargs):  # noqa: E501
        """指定时间段内加药统计文件导出 Export dosing daily statistic results of a certain period as an excel file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_download_dosing_statistic_daily_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类型 dosage type
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param str download_key: 下载key download key
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'category',
            'start_time',
            'end_time',
            'download_key'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_download_dosing_statistic_daily_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'category' in local_var_params and local_var_params['category'] is not None:  # noqa: E501
            query_params.append(('category', local_var_params['category']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501
        if 'download_key' in local_var_params and local_var_params['download_key'] is not None:  # noqa: E501
            query_params.append(('downloadKey', local_var_params['download_key']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/DownloadDosingStatisticDaily', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_abft_process_status_get(self, **kwargs):  # noqa: E501
        """获取生化池工艺运行状态 Get biochemical pool operation status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_abft_process_status_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AbftProcessStatusOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_abft_process_status_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_abft_process_status_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取生化池工艺运行状态 Get biochemical pool operation status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_abft_process_status_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AbftProcessStatusOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'production_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_abft_process_status_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetABFTProcessStatus', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AbftProcessStatusOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_anoxic_no3_get(self, **kwargs):  # noqa: E501
        """获取缺氧区出水硝酸盐 Get anoxic zone effluent nitrate concentration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_anoxic_no3_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SingleCodeDatasOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_anoxic_no3_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_anoxic_no3_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取缺氧区出水硝酸盐 Get anoxic zone effluent nitrate concentration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_anoxic_no3_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SingleCodeDatasOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'production_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_anoxic_no3_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetAnoxicNO3', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SingleCodeDatasOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_assembly_configs_get(self, **kwargs):  # noqa: E501
        """根据展示类别获取点位配置信息  # noqa: E501

        根据展示类别获取点位配置信息  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_assembly_configs_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int display_type_enum: 展示枚举
        :param str product_line: 产线
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AssemblyConfigOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_assembly_configs_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_assembly_configs_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据展示类别获取点位配置信息  # noqa: E501

        根据展示类别获取点位配置信息  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_assembly_configs_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int display_type_enum: 展示枚举
        :param str product_line: 产线
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AssemblyConfigOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'display_type_enum',
            'product_line'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_assembly_configs_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'display_type_enum' in local_var_params and local_var_params['display_type_enum'] is not None:  # noqa: E501
            query_params.append(('displayTypeEnum', local_var_params['display_type_enum']))  # noqa: E501
        if 'product_line' in local_var_params and local_var_params['product_line'] is not None:  # noqa: E501
            query_params.append(('productLine', local_var_params['product_line']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetAssemblyConfigs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AssemblyConfigOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_cd_addition_rate_get(self, **kwargs):  # noqa: E501
        """获取碳源投加速率 Get carbon source dosing rate data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_cd_addition_rate_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CdAdditionRateOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_cd_addition_rate_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_cd_addition_rate_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取碳源投加速率 Get carbon source dosing rate data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_cd_addition_rate_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CdAdditionRateOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'production_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_cd_addition_rate_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetCDAdditionRate', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CdAdditionRateOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_denitrification_rate_get(self, **kwargs):  # noqa: E501
        """获取反硝化速率 Get denitrification rate data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_denitrification_rate_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SingleCodeDatasOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_denitrification_rate_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_denitrification_rate_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取反硝化速率 Get denitrification rate data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_denitrification_rate_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SingleCodeDatasOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'production_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_denitrification_rate_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetDenitrificationRate', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SingleCodeDatasOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_dosing_log_get(self, **kwargs):  # noqa: E501
        """获取指定时间段内的加药报表 Get dosing logs of a certain period  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_dosing_log_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类型 dosage type
        :param str production_line: 产线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DosingLogOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_dosing_log_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_dosing_log_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取指定时间段内的加药报表 Get dosing logs of a certain period  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_dosing_log_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类型 dosage type
        :param str production_line: 产线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DosingLogOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'category',
            'production_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_dosing_log_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'category' in local_var_params and local_var_params['category'] is not None:  # noqa: E501
            query_params.append(('category', local_var_params['category']))  # noqa: E501
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetDosingLog', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DosingLogOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_dosing_parameter_get(self, **kwargs):  # noqa: E501
        """获取加药参数 Get dosing paramters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_dosing_parameter_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类别 dosage type
        :param str production_line_code: 产线编号 product line code
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DosingParameterOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_dosing_parameter_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_dosing_parameter_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取加药参数 Get dosing paramters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_dosing_parameter_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类别 dosage type
        :param str production_line_code: 产线编号 product line code
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DosingParameterOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'category',
            'production_line_code'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_dosing_parameter_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'category' in local_var_params and local_var_params['category'] is not None:  # noqa: E501
            query_params.append(('category', local_var_params['category']))  # noqa: E501
        if 'production_line_code' in local_var_params and local_var_params['production_line_code'] is not None:  # noqa: E501
            query_params.append(('productionLineCode', local_var_params['production_line_code']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetDosingParameter', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DosingParameterOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_dosing_statistic_dailys_get(self, **kwargs):  # noqa: E501
        """指定时间段内加药统计查询 Get dosing daily statistic results of a certain period  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_dosing_statistic_dailys_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类型 dosage type
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DosingStatisticDailysOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_dosing_statistic_dailys_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_dosing_statistic_dailys_get_with_http_info(self, **kwargs):  # noqa: E501
        """指定时间段内加药统计查询 Get dosing daily statistic results of a certain period  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_dosing_statistic_dailys_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int category: 加药类型 dosage type
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DosingStatisticDailysOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'category',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_dosing_statistic_dailys_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'category' in local_var_params and local_var_params['category'] is not None:  # noqa: E501
            query_params.append(('category', local_var_params['category']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetDosingStatisticDailys', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DosingStatisticDailysOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_inlet_load_get(self, **kwargs):  # noqa: E501
        """获取进水负荷 Get inlet water quality load data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_inlet_load_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[InletLoadOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_inlet_load_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_inlet_load_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取进水负荷 Get inlet water quality load data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_inlet_load_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 产线编号 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[InletLoadOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'production_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_inlet_load_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetInletLoad', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InletLoadOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_get_outlet_tn_get(self, **kwargs):  # noqa: E501
        """获取出水总氮 Get total effluent nitrogen concentration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_outlet_tn_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OutletTnOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_get_outlet_tn_get_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_get_outlet_tn_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取出水总氮 Get total effluent nitrogen concentration  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_get_outlet_tn_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OutletTnOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_get_outlet_tn_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/GetOutletTN', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OutletTnOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_intelligent_denitrification_save_dosing_parameter_post(self, **kwargs):  # noqa: E501
        """保存加药参数 Save dosing parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_save_dosing_parameter_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[DosingParamSettingDto] dosing_param_setting_dto:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_intelligent_denitrification_save_dosing_parameter_post_with_http_info(**kwargs)  # noqa: E501

    def api_intelligent_denitrification_save_dosing_parameter_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存加药参数 Save dosing parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_intelligent_denitrification_save_dosing_parameter_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[DosingParamSettingDto] dosing_param_setting_dto:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'dosing_param_setting_dto'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_intelligent_denitrification_save_dosing_parameter_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'dosing_param_setting_dto' in local_var_params:
            body_params = local_var_params['dosing_param_setting_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/IntelligentDenitrification/SaveDosingParameter', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class QueryOpcUaConfigOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'opc_flag': 'str',
        'opc_server_ip': 'str',
        'opc_server_port': 'str',
        'user_name': 'str',
        'password': 'str',
        'remarks': 'str'
    }

    attribute_map = {
        'id': 'id',
        'opc_flag': 'opcFlag',
        'opc_server_ip': 'opcServerIp',
        'opc_server_port': 'opcServerPort',
        'user_name': 'userName',
        'password': 'password',
        'remarks': 'remarks'
    }

    def __init__(self, id=None, opc_flag=None, opc_server_ip=None, opc_server_port=None, user_name=None, password=None, remarks=None, local_vars_configuration=None):  # noqa: E501
        """QueryOpcUaConfigOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._opc_flag = None
        self._opc_server_ip = None
        self._opc_server_port = None
        self._user_name = None
        self._password = None
        self._remarks = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.opc_flag = opc_flag
        self.opc_server_ip = opc_server_ip
        self.opc_server_port = opc_server_port
        self.user_name = user_name
        self.password = password
        self.remarks = remarks

    @property
    def id(self):
        """Gets the id of this QueryOpcUaConfigOutput.  # noqa: E501

        Id Id  # noqa: E501

        :return: The id of this QueryOpcUaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QueryOpcUaConfigOutput.

        Id Id  # noqa: E501

        :param id: The id of this QueryOpcUaConfigOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def opc_flag(self):
        """Gets the opc_flag of this QueryOpcUaConfigOutput.  # noqa: E501

        标识 mark  # noqa: E501

        :return: The opc_flag of this QueryOpcUaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._opc_flag

    @opc_flag.setter
    def opc_flag(self, opc_flag):
        """Sets the opc_flag of this QueryOpcUaConfigOutput.

        标识 mark  # noqa: E501

        :param opc_flag: The opc_flag of this QueryOpcUaConfigOutput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and opc_flag is None:  # noqa: E501
            raise ValueError("Invalid value for `opc_flag`, must not be `None`")  # noqa: E501

        self._opc_flag = opc_flag

    @property
    def opc_server_ip(self):
        """Gets the opc_server_ip of this QueryOpcUaConfigOutput.  # noqa: E501

        Ip Ip  # noqa: E501

        :return: The opc_server_ip of this QueryOpcUaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._opc_server_ip

    @opc_server_ip.setter
    def opc_server_ip(self, opc_server_ip):
        """Sets the opc_server_ip of this QueryOpcUaConfigOutput.

        Ip Ip  # noqa: E501

        :param opc_server_ip: The opc_server_ip of this QueryOpcUaConfigOutput.  # noqa: E501
        :type: str
        """

        self._opc_server_ip = opc_server_ip

    @property
    def opc_server_port(self):
        """Gets the opc_server_port of this QueryOpcUaConfigOutput.  # noqa: E501

        端口 port  # noqa: E501

        :return: The opc_server_port of this QueryOpcUaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._opc_server_port

    @opc_server_port.setter
    def opc_server_port(self, opc_server_port):
        """Sets the opc_server_port of this QueryOpcUaConfigOutput.

        端口 port  # noqa: E501

        :param opc_server_port: The opc_server_port of this QueryOpcUaConfigOutput.  # noqa: E501
        :type: str
        """

        self._opc_server_port = opc_server_port

    @property
    def user_name(self):
        """Gets the user_name of this QueryOpcUaConfigOutput.  # noqa: E501

        用户名 user name  # noqa: E501

        :return: The user_name of this QueryOpcUaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this QueryOpcUaConfigOutput.

        用户名 user name  # noqa: E501

        :param user_name: The user_name of this QueryOpcUaConfigOutput.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def password(self):
        """Gets the password of this QueryOpcUaConfigOutput.  # noqa: E501

        密码 password  # noqa: E501

        :return: The password of this QueryOpcUaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this QueryOpcUaConfigOutput.

        密码 password  # noqa: E501

        :param password: The password of this QueryOpcUaConfigOutput.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def remarks(self):
        """Gets the remarks of this QueryOpcUaConfigOutput.  # noqa: E501

        备注 remarks  # noqa: E501

        :return: The remarks of this QueryOpcUaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        """Sets the remarks of this QueryOpcUaConfigOutput.

        备注 remarks  # noqa: E501

        :param remarks: The remarks of this QueryOpcUaConfigOutput.  # noqa: E501
        :type: str
        """

        self._remarks = remarks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryOpcUaConfigOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryOpcUaConfigOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class IntelligentDeniConfigInOut(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'display_type': 'int',
        'display_type_name': 'str',
        'codes': 'str',
        'sub_type': 'str',
        'is_input_point': 'bool',
        'ext_info': 'str',
        'product_line': 'str',
        'category': 'int'
    }

    attribute_map = {
        'id': 'id',
        'display_type': 'displayType',
        'display_type_name': 'displayTypeName',
        'codes': 'codes',
        'sub_type': 'subType',
        'is_input_point': 'isInputPoint',
        'ext_info': 'extInfo',
        'product_line': 'productLine',
        'category': 'category'
    }

    def __init__(self, id=None, display_type=None, display_type_name=None, codes=None, sub_type=None, is_input_point=None, ext_info=None, product_line=None, category=None, local_vars_configuration=None):  # noqa: E501
        """IntelligentDeniConfigInOut - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._display_type = None
        self._display_type_name = None
        self._codes = None
        self._sub_type = None
        self._is_input_point = None
        self._ext_info = None
        self._product_line = None
        self._category = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if display_type is not None:
            self.display_type = display_type
        self.display_type_name = display_type_name
        self.codes = codes
        self.sub_type = sub_type
        if is_input_point is not None:
            self.is_input_point = is_input_point
        self.ext_info = ext_info
        self.product_line = product_line
        if category is not None:
            self.category = category

    @property
    def id(self):
        """Gets the id of this IntelligentDeniConfigInOut.  # noqa: E501

        配置ID config id  # noqa: E501

        :return: The id of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IntelligentDeniConfigInOut.

        配置ID config id  # noqa: E501

        :param id: The id of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def display_type(self):
        """Gets the display_type of this IntelligentDeniConfigInOut.  # noqa: E501

        展示类型枚举 display type  # noqa: E501

        :return: The display_type of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: int
        """
        return self._display_type

    @display_type.setter
    def display_type(self, display_type):
        """Sets the display_type of this IntelligentDeniConfigInOut.

        展示类型枚举 display type  # noqa: E501

        :param display_type: The display_type of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: int
        """

        self._display_type = display_type

    @property
    def display_type_name(self):
        """Gets the display_type_name of this IntelligentDeniConfigInOut.  # noqa: E501

        展示类型名称 display type name  # noqa: E501

        :return: The display_type_name of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._display_type_name

    @display_type_name.setter
    def display_type_name(self, display_type_name):
        """Sets the display_type_name of this IntelligentDeniConfigInOut.

        展示类型名称 display type name  # noqa: E501

        :param display_type_name: The display_type_name of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._display_type_name = display_type_name

    @property
    def codes(self):
        """Gets the codes of this IntelligentDeniConfigInOut.  # noqa: E501

        系统点位编码，逗号分割 system point codes, seperated by comma  # noqa: E501

        :return: The codes of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._codes

    @codes.setter
    def codes(self, codes):
        """Sets the codes of this IntelligentDeniConfigInOut.

        系统点位编码，逗号分割 system point codes, seperated by comma  # noqa: E501

        :param codes: The codes of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._codes = codes

    @property
    def sub_type(self):
        """Gets the sub_type of this IntelligentDeniConfigInOut.  # noqa: E501

        点位类型 point type  # noqa: E501

        :return: The sub_type of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._sub_type

    @sub_type.setter
    def sub_type(self, sub_type):
        """Sets the sub_type of this IntelligentDeniConfigInOut.

        点位类型 point type  # noqa: E501

        :param sub_type: The sub_type of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._sub_type = sub_type

    @property
    def is_input_point(self):
        """Gets the is_input_point of this IntelligentDeniConfigInOut.  # noqa: E501

        是否为输入点位 if it is an online point for input  # noqa: E501

        :return: The is_input_point of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: bool
        """
        return self._is_input_point

    @is_input_point.setter
    def is_input_point(self, is_input_point):
        """Sets the is_input_point of this IntelligentDeniConfigInOut.

        是否为输入点位 if it is an online point for input  # noqa: E501

        :param is_input_point: The is_input_point of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: bool
        """

        self._is_input_point = is_input_point

    @property
    def ext_info(self):
        """Gets the ext_info of this IntelligentDeniConfigInOut.  # noqa: E501

        扩展信息，生化池序号 extend information for biochemical pool index  # noqa: E501

        :return: The ext_info of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._ext_info

    @ext_info.setter
    def ext_info(self, ext_info):
        """Sets the ext_info of this IntelligentDeniConfigInOut.

        扩展信息，生化池序号 extend information for biochemical pool index  # noqa: E501

        :param ext_info: The ext_info of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._ext_info = ext_info

    @property
    def product_line(self):
        """Gets the product_line of this IntelligentDeniConfigInOut.  # noqa: E501

        生产线代码 product line code  # noqa: E501

        :return: The product_line of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this IntelligentDeniConfigInOut.

        生产线代码 product line code  # noqa: E501

        :param product_line: The product_line of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def category(self):
        """Gets the category of this IntelligentDeniConfigInOut.  # noqa: E501

        药剂投加类别  # noqa: E501

        :return: The category of this IntelligentDeniConfigInOut.  # noqa: E501
        :rtype: int
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this IntelligentDeniConfigInOut.

        药剂投加类别  # noqa: E501

        :param category: The category of this IntelligentDeniConfigInOut.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IntelligentDeniConfigInOut):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IntelligentDeniConfigInOut):
            return True

        return self.to_dict() != other.to_dict()
